bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.delete
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.delete